StorageBase class abstract

Implementers

Constructors

StorageBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

containsKey(String key) → Future<bool>
delete(String key) → Future<bool>
deleteAll() → Future<void>
getObject(String key) → Future<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String key) → Future<String?>
readAll() → Future<Map<String, String>>
readBool(String key) → Future<bool>
setObject(Map<String, dynamic> object, String key) → Future<void>
toString() → String
A string representation of this object.
inherited
write(String key, String value) → Future<bool>
writeBool(String key, bool value) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited